"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_native_1 = require("react-native");
const __1 = __importDefault(require(".."));
const react_native_device_info_1 = __importDefault(require("react-native-device-info"));
const helper_1 = __importDefault(require("../utils/helper"));
const KEY_INSTALL_REFERRER = "ea-android-referrer";
const KEY_EOS = "eos";
const KEY_EHW = "ehw";
const KEY_EHW_IDENTIFIER = "ehw-identifier";
const KEY_ADINFO_IS_LAT = "ea-android-islat";
const KEY_EUIDL = "euidl";
const KEY_URL = "url";
const KEY_APPNAME = "ea-appname";
const KEY_ADINFO_ID = "ea-android-adid";
const KEY_EPOCH = "ereplay-time";
const KEY_APP_VERSION_NAME = "ea-appversion";
const KEY_APP_VERSION_CODE = "ea-appversionbuild";
const KEY_IS_TV = "ea-apptv";
const KEY_MAC = "ea-android-mac";
const KEY_SDK_VERSION = "ea-android-sdk-version";
const KEY_PAGE_CFLAG = "cflag";
const KEY_IDFV = "ea-ios-idfv";
const KEY_IDFA = "ea-ios-idfa";
const KEY_ADTRACKING_ENABLED = "ea-ios-islat";
//- page keys
const KEY_PAGE_LATITUDE = "ea-lat";
const KEY_PAGE_LONGITUDE = "ea-lon";
const KEY_PAGE_PATH = "path";
const KEY_PAGE_EMAIL = "email";
const KEY_PAGE_UID = "uid";
const KEY_PAGE_PROFILE = "profile";
const KEY_PAGE_GROUP = "pagegroup";
const KEY_PAGE_ACTION = "action";
const KEY_PAGE_PROPERTY = "property";
const KEY_PAGE_NEW_CUSTOMER = "newcustomer";
let androidInstallReferrer = null;
class EaGeneric {
    constructor(builder) {
        this.mInternals = builder.internals;
        this.mPages = builder.pages;
        this.mProperties = builder.properties;
    }
    getJson() {
        return helper_1.default.mergeProperties(this.mInternals, this.mPages, this.mProperties);
    }
}
EaGeneric.Builder = class {
    constructor(path) {
        this.properties = {};
        this.internals = {};
        this.pages = {};
        this.initInternalParams();
        if (!path.startsWith('/')) {
            path = '/' + path;
        }
        this.pages.path = path;
    }
    initInternalParams() {
        //this.internals["edebug"] = "on";
        this.internals[KEY_EOS] = react_native_1.Platform.OS === "android" ? "Android" : "" + react_native_device_info_1.default.getSystemVersion();
        if (react_native_1.Platform.OS === "android") {
            let self = this;
            react_native_device_info_1.default.getManufacturer().then((manufacturer) => {
                self.internals[KEY_EHW] = manufacturer;
            });
            react_native_device_info_1.default.getAndroidId().then((androidId) => {
                self.internals[KEY_EUIDL] = androidId;
            });
            react_native_device_info_1.default.getMacAddress().then((mac) => {
                self.internals[KEY_MAC] = mac;
            });
            //this.internals[KEY_EHW] = DeviceInfo.getManufacturer().then().getManufacturerSync() + " " + DeviceInfo.getModel();
            //this.internals[KEY_EUIDL] = DeviceInfo.getAndroidIdSync();
            //this.internals[KEY_MAC] = DeviceInfo.getMacAddressSync();
            //params[KEY_SDK_VERSION] = ""; //TODO?
            if (androidInstallReferrer) {
                self.internals[KEY_INSTALL_REFERRER] = androidInstallReferrer;
            }
        }
        else {
            this.internals[KEY_EHW] = react_native_device_info_1.default.getModel();
            this.internals[KEY_EHW_IDENTIFIER] = react_native_device_info_1.default.getDeviceId();
            react_native_device_info_1.default.getUniqueId().then((uniqueId) => {
                this.internals[KEY_IDFV] = uniqueId;
            });
        }
        this.internals[react_native_1.Platform.OS === "android" ? KEY_ADINFO_ID : KEY_IDFA] = __1.default.getAdInfoId();
        this.internals[react_native_1.Platform.OS === "android" ? KEY_ADINFO_IS_LAT : KEY_ADTRACKING_ENABLED] = __1.default.getAdInfoIsLAT();
        /*DeviceInfo.getInstallerPackageName().then((installerPackageName) => {
          let appName = installerPackageName;
          this.internals[KEY_APPNAME] = appName;
          this.internals[KEY_URL] = "http://" + appName;
        });*/
        let appName = "am1.eulerian.net/andrea/test";
        this.internals[KEY_APPNAME] = appName;
        this.internals[KEY_URL] = "http://" + appName;
        this.internals[KEY_EPOCH] = Math.floor(Date.now() / 1000);
        this.internals[KEY_APP_VERSION_CODE] = react_native_device_info_1.default.getBuildNumber();
        this.internals[KEY_APP_VERSION_NAME] = react_native_device_info_1.default.getVersion();
        return this.internals;
    }
    set(key, value) {
        this.properties[key] = value;
        return this;
    }
    static setAndroidInstallReferrer(value) {
        androidInstallReferrer = value;
    }
    setLocation(latitude, longitude) {
        this.pages.latitude = latitude;
        this.pages.longitude = longitude;
        return this;
    }
    setNewCustomer(newCustomer) {
        if (newCustomer) {
            this.pages.newcustomer = '1';
        }
        return this;
    }
    setEmail(email) {
        if (email) {
            this.pages.email = email;
        }
        return this;
    }
    setPageGroup(group) {
        if (group) {
            this.pages.pagegroup = group;
        }
        return this;
    }
    setProfile(profile) {
        if (profile) {
            this.pages.profile = profile;
        }
        return this;
    }
    setUID(uid) {
        if (uid) {
            this.pages.uid = uid;
        }
        return this;
    }
    setAction(action) {
        if (action) {
            this.pages.action = action.getJson();
        }
        return this;
    }
    setProperty(property) {
        if (property) {
            this.pages.property = property.getJson();
        }
        return this;
    }
    setCFlag(cflag) {
        if (cflag) {
            this.pages.cflag = cflag.getJson();
        }
        return this;
    }
    build() {
        return new EaGeneric(this);
    }
};
exports.default = EaGeneric;
