"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const async_storage_1 = __importDefault(require("@react-native-async-storage/async-storage"));
const INSTALL_REFERRER_HAS_ALREADY_BEEN_SENT_ONCE = "referrer_sent_v1_8_0";
const KEY_REFERRER = "referrer";
const KEY_ADVERTISING_ID = "id";
const KEY_ADVERTISING_IS_LAT = "isLAT";
class PersistentIdentity {
    static getValue(key) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const value = yield async_storage_1.default.getItem(key);
                return value;
            }
            catch (error) {
                console.error('Errore nel recupero dei dati:', error);
                return null;
            }
        });
    }
    static setValue(key, value) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield async_storage_1.default.setItem(key, value);
                console.info('Salvato il dato:', key, ' con valore:', value);
            }
            catch (error) {
                console.error('Errore nel salvataggio dei dati:', error);
            }
        });
    }
    static shouldFetchInstallReferrer() {
        return __awaiter(this, void 0, void 0, function* () {
            const value = this.getValue(INSTALL_REFERRER_HAS_ALREADY_BEEN_SENT_ONCE);
            return value != null && Boolean(value);
        });
    }
    static isInstallReferrerSent() {
        return __awaiter(this, void 0, void 0, function* () {
            const value = this.getValue(INSTALL_REFERRER_HAS_ALREADY_BEEN_SENT_ONCE);
            if (value != null)
                return Boolean(value);
            else
                return false;
        });
    }
    static getInstallReferrer() {
        return __awaiter(this, void 0, void 0, function* () {
            const value = yield this.getValue(KEY_REFERRER);
            return value;
        });
    }
    static getAdvertisingId() {
        return __awaiter(this, void 0, void 0, function* () {
            const value = yield this.getValue(KEY_ADVERTISING_ID);
            return value;
        });
    }
    static getAdvertisingIsLat() {
        return __awaiter(this, void 0, void 0, function* () {
            const value = yield this.getValue(KEY_ADVERTISING_IS_LAT);
            if (value != null)
                return Boolean(value);
            else
                return false;
        });
    }
    static saveInstallReferrer(value) {
        return __awaiter(this, void 0, void 0, function* () {
            this.setValue(KEY_REFERRER, value);
        });
    }
    static shouldSendInstallReferrer() {
        return __awaiter(this, void 0, void 0, function* () {
            const isInstallReferrerSent = yield this.isInstallReferrerSent();
            const isInstallReferrerAvailable = yield this.getInstallReferrer();
            return isInstallReferrerAvailable && (isInstallReferrerSent == null || !Boolean(isInstallReferrerSent));
        });
    }
    static setInstallReferrerSent() {
        return __awaiter(this, void 0, void 0, function* () {
            this.setValue(INSTALL_REFERRER_HAS_ALREADY_BEEN_SENT_ONCE, "true");
        });
    }
}
exports.default = PersistentIdentity;
