"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_native_1 = require("react-native");
const config_1 = require("./config");
const connectivityHelper_1 = __importDefault(require("./connectivityHelper"));
const eaLog_1 = __importDefault(require("../models/eaLog"));
const fileHelper_1 = __importDefault(require("./fileHelper"));
const httpHelper_1 = __importDefault(require("./httpHelper"));
const persistentIdentity_1 = __importDefault(require("./persistentIdentity"));
const storedPropertiesTracker_1 = __importDefault(require("./storedPropertiesTracker"));
const __1 = __importDefault(require(".."));
const eaGeneric_1 = __importDefault(require("../models/eaGeneric"));
class PropertiesTracker {
    static run(properties) {
        return __awaiter(this, void 0, void 0, function* () {
            if (react_native_1.Platform.OS === "android") {
                if (yield persistentIdentity_1.default.shouldSendInstallReferrer()) {
                    var installReferrer = yield persistentIdentity_1.default.getInstallReferrer();
                    eaLog_1.default.debug("Tracking properties for the first time, add install referrer to it");
                    if (installReferrer) {
                        eaGeneric_1.default.Builder.setAndroidInstallReferrer(installReferrer);
                        persistentIdentity_1.default.setInstallReferrerSent();
                    }
                }
            }
            var propertiesToString = JSON.stringify(properties);
            eaLog_1.default.debug("Tracking properties");
            if (yield !connectivityHelper_1.default.isConnected()) {
                eaLog_1.default.info("-> no network access. Properties is being stored and will be sent later.", true);
                fileHelper_1.default.appendLine(propertiesToString);
                __1.default.getEventEmitter().emit("message_retry", config_1.NO_INTERNET_RETRY_DELAY_MILLIS);
                return;
            }
            const storedProperties = yield fileHelper_1.default.getLines();
            if (storedProperties.length == 0) {
                eaLog_1.default.debug("DEVO FARE LA CHIAMATA");
                var success = httpHelper_1.default.postData("[" + propertiesToString + "]");
                if (!success) {
                    eaLog_1.default.debug("-> synchronization failed. Will retry if no other pending track is found.");
                    fileHelper_1.default.appendLine(propertiesToString);
                    __1.default.getEventEmitter().emit("message_retry", config_1.POST_FAILED_RETRY_DELAY_MILLIS);
                }
                else {
                    eaLog_1.default.info("-> properties tracked !", true);
                }
                return;
            }
            eaLog_1.default.debug("-> " + storedProperties.length + " stored properties found, current properties added to history to " +
                "be sent with stored ones.");
            fileHelper_1.default.appendLine(propertiesToString); //we treat the current properties as a stored properties (history)
            storedPropertiesTracker_1.default.run();
        });
    }
}
exports.default = PropertiesTracker;
