"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const connectivityHelper_1 = __importDefault(require("./connectivityHelper"));
const eaLog_1 = __importDefault(require("../models/eaLog"));
const __1 = __importDefault(require(".."));
const config_1 = require("./config");
const fileHelper_1 = __importDefault(require("./fileHelper"));
const httpHelper_1 = __importDefault(require("./httpHelper"));
class StoredPropertiesTracker {
    static run() {
        return __awaiter(this, void 0, void 0, function* () {
            eaLog_1.default.debug("Tracking stored properties");
            if (yield !connectivityHelper_1.default.isConnected()) {
                eaLog_1.default.info("-> no network access. Properties is being stored and will be sent later.", true);
                __1.default.getEventEmitter().emit("message_retry", config_1.NO_INTERNET_RETRY_DELAY_MILLIS);
            }
            const storedProperties = yield fileHelper_1.default.getLines();
            if (storedProperties.length == 0) {
                eaLog_1.default.debug("-> no properties stored.");
                return;
            }
            eaLog_1.default.debug("-> " + storedProperties.length + " stored properties found. Added for synchronization.");
            var result = yield this.postStoredProperties(storedProperties);
            if (result == -1) {
                __1.default.getEventEmitter().emit("message_retry", config_1.POST_FAILED_RETRY_DELAY_MILLIS);
            }
            else {
                eaLog_1.default.debug("-> all properties tracked successfully. Stored properties is now empty.");
            }
        });
    }
    static postStoredProperties(storedProperties) {
        return __awaiter(this, void 0, void 0, function* () {
            let counter = 0;
            let jsonArray = [];
            while (counter < storedProperties.length) {
                const line = storedProperties[counter];
                try {
                    const lineJson = JSON.parse(line);
                    jsonArray.push(lineJson);
                    if (counter === storedProperties.length - 1 || // Ultimo elemento
                        JSON.stringify(jsonArray).length + storedProperties[counter + 1].length > config_1.MAX_UNZIPPED_BYTES_PER_SEND) {
                        // no more data OR json array is becoming too big -> send it
                        const success = yield httpHelper_1.default.postData(JSON.stringify(jsonArray));
                        if (success) {
                            yield fileHelper_1.default.deleteLines(jsonArray.length);
                            jsonArray = []; // re-init in case the is still pending data.
                            eaLog_1.default.debug('-> properties tracked !');
                        }
                        else {
                            // something went wrong, will try on track() next call. This avoid infinite loop.
                            eaLog_1.default.debug('-> la sincronizzazione è fallita. Riproverà in seguito.');
                            return -1;
                        }
                    }
                }
                catch (e) {
                    eaLog_1.default.error(`Errore nel codificare in JSON le proprietà: ${line}. Eccezione: ${e}`);
                }
                counter++;
            }
            return counter;
        });
    }
}
exports.default = StoredPropertiesTracker;
